🔖 [Table of Contents](../../README.md) / [Concepts](../README.md)

# Specialized Tasks

- [DockerComposeTask](docker-compose-task.md)
- [ResourceMaker](resource-maker.md)
- [Notifier](notifider.md)
- [RemoteCmdTask](remote-cmd-task.md)
- [RsyncTask](rsync-task.md)
- [RecurringTask](recurring-task.md)
- [Checker](checker.md)
- [FlowTask](flow-task.md)

🔖 [Table of Contents](../../README.md) / [Concepts](../README.md)
